@@ -46,6 +46,7 @@ SUPPORTED_VALUES = {
     "nsem": [ "count", "time", "mass", "measure" ],
 };
 
+rule_id = 0
 
 def getstrval(v):
     if v is None:
@@ -100,7 +101,9 @@ def rule(
             val = getstrval(locals()[key])
             if val is not None:
                 output.append(f"{key}={val}")
-    return ",".join(output)
+    global rule_id
+    rule_id = rule_id + 1
+    return f"rule_id={rule_id}|rule_id|" + ",".join(output)
 
 class gram():
     def __init__(self, value):
